import React from 'react';
import { DialogProps } from '@mui/material/Dialog';
import { SxProps, Theme } from '@mui/material/styles';
/**
 * Component that renders a basic dialog with a title, body description, and a close button.
 *
 * @param title to show text in the title
 * @param body text to show in the body
 * @param onClose function to call when the close button is clicked
 * @param props all other props will be spread to the underlying Dialog component
 * @param dismissButtonText text to show in the close button
 *
 * @category Component
 */
export declare const DialogTitleStyles: (theme: Theme) => SxProps<Theme>;
export declare const DialogContentStyles: (theme: Theme) => SxProps<Theme>;
export declare const DialogActionsStyles: (theme: Theme) => SxProps<Theme>;
export declare const DialogButtonStyles: (fullWidth?: boolean) => SxProps<Theme>;
export type BasicDialogProps = Omit<DialogProps, 'open'> & {
    /**
     * The title for the screen
     */
    title?: string;
    /**
     * The text to show in the main dialog body
     */
    body?: string;
    /**
     * The function to call when the close button is clicked
     * @returns void
     */
    onClose?: () => void;
    /**
     * The text to show in the close button
     */
    dismissButtonText?: string;
    /**
     * Set the open / closed state of the dialog
     * @default false
     */
    open?: boolean;
};
export declare const BasicDialog: React.FC<React.PropsWithChildren<React.PropsWithChildren<BasicDialogProps>>>;
