"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetPassword = void 0;
var react_1 = __importStar(require("react"));
var styles_1 = require("@mui/material/styles");
var CheckCircleOutlined_1 = __importDefault(require("@mui/icons-material/CheckCircleOutlined"));
var styles_2 = require("../../styles");
var PasswordTextField_1 = require("../PasswordTextField");
var PasswordRequirements_1 = require("../PasswordRequirements");
/**
 * Component that renders a change password form with a new password and confirm password inputs.
 * It includes callbacks so you can respond to changes in the inputs.
 *
 * @param onPasswordChange called when the new password or confirm new password fields value changes
 * @param initialNewPasswordValue initial value for the new password field
 * @param initialConfirmPasswordValue initial value for the confirm password field
 * @param passwordRequirements requirements to set password
 * @param newPasswordLabel label for the new password field (default = 'Password')
 * @param confirmPasswordLabel label for the confirm password field (default = 'Confirm')
 * @param passwordRef ref to forward to the password input.
 * @param confirmRef ref to forward to the confirm password input.
 * @param passwordNotMatchError text for showing message when passwords do not match.
 * @param onSubmit function to call when the form is submitted
 *
 * @category Component
 */
var SetPassword = function (props) {
    var newPasswordLabel = props.newPasswordLabel, _a = props.initialNewPasswordValue, initialNewPasswordValue = _a === void 0 ? '' : _a, confirmPasswordLabel = props.confirmPasswordLabel, _b = props.initialConfirmPasswordValue, initialConfirmPasswordValue = _b === void 0 ? '' : _b, passwordRequirements = props.passwordRequirements, onPasswordChange = props.onPasswordChange, children = props.children, passwordRef = props.passwordRef, confirmRef = props.confirmRef, passwordNotMatchError = props.passwordNotMatchError, onSubmit = props.onSubmit;
    var theme = (0, styles_1.useTheme)();
    // Local State
    var _c = (0, react_1.useState)(initialNewPasswordValue), passwordInput = _c[0], setPasswordInput = _c[1];
    var _d = (0, react_1.useState)(initialConfirmPasswordValue), confirmInput = _d[0], setConfirmInput = _d[1];
    var _e = (0, react_1.useState)(false), shouldValidateConfirmPassword = _e[0], setShouldValidateConfirmPassword = _e[1];
    var _f = (0, react_1.useState)(false), shouldValidatePassword = _f[0], setShouldValidatePassword = _f[1];
    var onPassChange = (0, react_1.useCallback)(function (newPassword) {
        setPasswordInput(newPassword);
        onPasswordChange === null || onPasswordChange === void 0 ? void 0 : onPasswordChange({ password: newPassword, confirm: confirmInput });
    }, [setPasswordInput, onPasswordChange, confirmInput]);
    var onConfirmChange = (0, react_1.useCallback)(function (newConfirm) {
        setConfirmInput(newConfirm);
        onPasswordChange === null || onPasswordChange === void 0 ? void 0 : onPasswordChange({ password: passwordInput, confirm: newConfirm });
    }, [setConfirmInput, onPasswordChange, passwordInput]);
    var hasConfirmPasswordError = (0, react_1.useCallback)(function () { return shouldValidateConfirmPassword && confirmInput.length !== 0 && confirmInput !== passwordInput; }, [shouldValidateConfirmPassword, confirmInput, passwordInput]);
    var isValidPassword = (0, react_1.useCallback)(function () {
        for (var i = 0; i < passwordRequirements.length; i++) {
            if (!new RegExp(passwordRequirements[i].regex).test(passwordInput))
                return false;
        }
        return true;
    }, [passwordRequirements, passwordInput]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        children,
        react_1.default.createElement(PasswordTextField_1.PasswordTextField, { id: "password", "data-testid": "password", name: "password", inputRef: passwordRef, label: newPasswordLabel, value: passwordInput, onChange: function (evt) { return onPassChange(evt.target.value); }, sx: (0, styles_2.TextFieldStyles)(theme), onKeyUp: function (e) {
                if (e.key === 'Enter' && confirmRef.current) {
                    confirmRef.current.focus();
                }
            }, error: shouldValidatePassword && !isValidPassword(), onBlur: function () { return setShouldValidatePassword(true); } }),
        passwordRequirements && passwordRequirements.length > 0 && (react_1.default.createElement(PasswordRequirements_1.PasswordRequirements, { sx: { mt: 2 }, passwordText: passwordInput, passwordRequirements: passwordRequirements })),
        react_1.default.createElement(PasswordTextField_1.PasswordTextField, { id: "confirm", "data-testid": "confirm", name: "confirm", inputRef: confirmRef, label: confirmPasswordLabel, sx: (0, styles_2.TextFieldStyles)(theme), value: confirmInput, onChange: function (evt) { return onConfirmChange(evt.target.value); }, onKeyUp: function (e) {
                if (e.key === 'Enter' && onSubmit)
                    onSubmit();
            }, error: hasConfirmPasswordError(), helperText: hasConfirmPasswordError() ? passwordNotMatchError : '', icon: confirmInput.length !== 0 && isValidPassword() && confirmInput === passwordInput ? (react_1.default.createElement(CheckCircleOutlined_1.default, { "data-testid": "check", color: "success" })) : undefined, onBlur: function () { return setShouldValidateConfirmPassword(true); } })));
};
exports.SetPassword = SetPassword;
