"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContactSupportScreen = void 0;
var react_1 = __importDefault(require("react"));
var icons_material_1 = require("@mui/icons-material");
var ContactSupportScreenBase_1 = require("./ContactSupportScreenBase");
var hooks_1 = require("../../hooks");
var contexts_1 = require("../../contexts");
/**
 * Component renders a screen with contact information for support with the application.
 * Contact information is pulled from the context passed into the workflow.
 *
 * @param title the title for the screen
 * @param icon the icon to display in the header
 * @param emailSupportTitle text to display as the contact support title
 * @param emailSupportContent content to display as the contact support content
 * @param phoneSupportTitle text to display as the phone support title
 * @param phoneSupportContent content to display as the phone support content
 * @param contactEmail to display the contact email
 * @param contactPhone to display contact phone number
 * @param dismissButtonLabel to display label for the button
 * @param onDismiss function to call when user clicks button
 * @param slots used for each slot in `ContactSupportScreen`
 * @param slotProps applied to each slot
 * @param WorkflowCardBaseProps props that will be passed to the WorkflowCard component
 * @param WorkflowCardHeaderProps props that will be passed to the WorkflowCardHeader component
 * @param WorkflowCardInstructionProps props that will be passed to the WorkflowCardInstructions component
 * @param WorkflowCardActionsProps props that will be passed to the WorkflowCardActions component
 *
 * @category Component
 */
var ContactSupportScreen = function (props) {
    var t = (0, hooks_1.useLanguageLocale)().t;
    var _a = (0, contexts_1.useAuthContext)(), navigate = _a.navigate, routeConfig = _a.routeConfig;
    var _b = props.icon, icon = _b === void 0 ? react_1.default.createElement(icons_material_1.ChatBubbleOutline, { color: 'primary', sx: { fontSize: 70 } }) : _b, _c = props.emailSupportTitle, emailSupportTitle = _c === void 0 ? t('bluiAuth:CONTACT_SUPPORT.GENERAL_QUESTIONS') : _c, _d = props.phoneSupportTitle, phoneSupportTitle = _d === void 0 ? t('bluiAuth:CONTACT_SUPPORT.EMERGENCY_SUPPORT') : _d, _e = props.contactEmail, contactEmail = _e === void 0 ? 'something@email.com' : _e, _f = props.contactPhone, contactPhone = _f === void 0 ? '1-800-123-4567' : _f, _g = props.dismissButtonLabel, dismissButtonLabel = _g === void 0 ? t('bluiCommon:ACTIONS.OKAY') : _g, WorkflowCardHeaderProps = props.WorkflowCardHeaderProps, WorkflowCardActionsProps = props.WorkflowCardActionsProps;
    var workflowCardHeaderProps = __assign({ title: t('bluiAuth:USER_MENU.CONTACT_US') }, WorkflowCardHeaderProps);
    var workflowCardActionsProps = __assign(__assign({ nextLabel: t('bluiCommon:ACTIONS.OKAY'), showNext: true, canGoNext: true, fullWidthButton: true }, WorkflowCardActionsProps), { onNext: function () {
            var _a;
            navigate(routeConfig.LOGIN);
            (_a = WorkflowCardActionsProps === null || WorkflowCardActionsProps === void 0 ? void 0 : WorkflowCardActionsProps.onNext) === null || _a === void 0 ? void 0 : _a.call(WorkflowCardActionsProps);
        } });
    return (react_1.default.createElement(ContactSupportScreenBase_1.ContactSupportScreenBase, { WorkflowCardHeaderProps: workflowCardHeaderProps, icon: icon, emailSupportTitle: emailSupportTitle, phoneSupportTitle: phoneSupportTitle, contactEmail: contactEmail, contactPhone: contactPhone, dismissButtonLabel: dismissButtonLabel, WorkflowCardActionsProps: workflowCardActionsProps }));
};
exports.ContactSupportScreen = ContactSupportScreen;
